@@ -47,12 +47,9 @@ SUPPORTED_LANGUAGES = "en,fr,de,nl,es,pt,it,zh,ar,ru"
 
 
 class SpacyMatcherAnnotator(AnnotatorBase):
-    (
-        """SpacyMatcher annotator using the [spacy rule-matching engine](https://spacy.io/usage/rule-based-matching#matcher).
+    __doc__ = """SpacyMatcher annotator using the [spacy rule-matching engine](https://spacy.io/usage/rule-based-matching#matcher).
     #need-segments
-    #languages:"""
-        + SUPPORTED_LANGUAGES
-    )
+    #languages:""" + SUPPORTED_LANGUAGES
 
     def annotate(
         self, documents: List[Document], parameters: AnnotatorParameters
